/*
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package net.sweetohm.ant.server;

import java.net.Socket;
import java.io.Reader;
import java.io.InputStreamReader;
import java.io.Writer;
import java.io.OutputStreamWriter;
import java.util.List;
import java.util.ArrayList;

/**
 * Ant server test client. You may use this example to integrate client in
 * in your Java source code.
 *
 * @author <a href="mailto:casa@sweetohm.net">Michel CASABIANCA</a>
 * @version 1.0
 */
public class Client {

    /** The host of the running Ant server */
    String host= "localhost";
    /** The port of the running Ant server */
    int port= 5393;
    /** The command to send to the server */
    String command= "";

    /**
     * Method main.
     * 
     * @param args The command line arguments.
     * @throws Exception If problem occurs.
     */
    public static void main(String[] args) throws Exception {
        Client client= new Client(args);
        client.run();
    }

    /**
     * Constructor for the Client.
     * 
     * @param args Commend line arguments.
     */
    public Client(String[] args) {
        for (int i= 0; i < args.length; i++) {
            if (args[i].equals("-host")) {
                host= args[++i];
            } else if (args[i].equals("-port")) {
                port= Integer.parseInt(args[++i]);
            } else
                command += args[i].trim() + " ";
        }
    }

    /**
     * Method run. The body of the client.
     * 
     * @throws Exception If a problem occurs.
     */
    void run() throws Exception {
        Socket socket= new Socket(host, port);
        Reader in= new InputStreamReader(socket.getInputStream());
        Writer out= new OutputStreamWriter(socket.getOutputStream());
        out.write(command + "\n");
        out.flush();
        int c= -1;
        while ((c= in.read()) > -1) {
            System.out.write((char) c);
            System.out.flush();
        }
        socket.close();
    }
}
